==> crm-commom-1.1.7.release.jar: com/biz/crm/config/LoginInterceptor.java <==
package com.biz.crm.config;

import com.biz.crm.base.config.ThreadLocalUtil;
import com.biz.crm.common.GlobalParam;
import com.biz.crm.util.StringUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections4.MapUtils;
import org.springframework.lang.Nullable;
import org.springframework.stereotype.Component;
import org.springframework.web.servlet.HandlerInterceptor;
import org.springframework.web.servlet.handler.HandlerInterceptorAdapter;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Map;
import java.util.Objects;
import java.util.concurrent.ConcurrentHashMap;

/**
 * @author jianglong
 * @version V1.0
 * @Package com.biz.crm.config
 * @Description: TODO
 * @date 2020/8/28 下午2:23
 */
@Slf4j
public class LoginInterceptor implements HandlerInterceptor {
    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        ThreadLocalUtil.clear();
        String token = request.getHeader(GlobalParam.TOKEN);
        if(StringUtils.isEmpty(token)){
            token = request.getHeader(GlobalParam.WEBSOCT_TOKEN);
        }
        Map parameterMap = request.getParameterMap();
        Object menuCode = parameterMap.get(GlobalParam.MENU_CODE);
        Object functionCode = parameterMap.get(GlobalParam.FUNCTION_CODE);
        ConcurrentHashMap<String,Object> map = new ConcurrentHashMap<>();
        if(StringUtils.isNotEmpty(token)){
            map.put(GlobalParam.TOKEN,token);
        }
        if(Objects.nonNull(menuCode)){
            map.put(GlobalParam.MENU_CODE,menuCode.toString());
        }
        if(Objects.nonNull(functionCode)){
            map.put(GlobalParam.FUNCTION_CODE,functionCode.toString());
        }
        if(MapUtils.isNotEmpty(map)){
            ThreadLocalUtil.stObj(map);
        }
        return true;
    }



//    /**
//     * 登录失效返回
//     *
//     * @param response
//     * @throws Exception
//     */
//    private void loginVaild(HttpServletResponse response) throws Exception {
//        Result result = new Result();
//        result.error401("请重新登录");
//        response.setContentType("application/json");
//        PrintWriter out = response.getWriter();
//        out.print(JSON.toJSONString(result));
//        out.flush();
//    }
    @Override
    public void afterCompletion(HttpServletRequest request, HttpServletResponse response, Object handler, @Nullable Exception ex) throws Exception {
        ThreadLocalUtil.clear();
    }
}

==> crm-commom-1.1.9.10.release.jar: com/biz/crm/config/LoginInterceptor.java <==
package com.biz.crm.config;

import com.biz.crm.base.config.ThreadLocalUtil;
import com.biz.crm.common.GlobalParam;
import com.biz.crm.util.StringUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections4.MapUtils;
import org.springframework.lang.Nullable;
import org.springframework.stereotype.Component;
import org.springframework.web.servlet.HandlerInterceptor;
import org.springframework.web.servlet.handler.HandlerInterceptorAdapter;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Map;
import java.util.Objects;
import java.util.concurrent.ConcurrentHashMap;

/**
 * @author jianglong
 * @version V1.0
 * @Package com.biz.crm.config
 * @Description: TODO
 * @date 2020/8/28 下午2:23
 */
@Slf4j
public class LoginInterceptor implements HandlerInterceptor {
    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        ThreadLocalUtil.clear();
        String token = request.getHeader(GlobalParam.TOKEN);
        String menuCode = request.getHeader(GlobalParam.MENU_CODE);
        String functionCode = request.getHeader(GlobalParam.FUNCTION_CODE);
        if(StringUtils.isEmpty(token)){
            token = request.getHeader(GlobalParam.WEBSOCT_TOKEN);
        }
        ConcurrentHashMap<String,Object> map = new ConcurrentHashMap<>();
        if(StringUtils.isNotEmpty(token)){
            map.put(GlobalParam.TOKEN,token);
        }
        if(StringUtils.isNotEmpty(menuCode)){
            map.put(GlobalParam.MENU_CODE,menuCode);
        }
        if(StringUtils.isNotEmpty(functionCode)){
            map.put(GlobalParam.FUNCTION_CODE,functionCode);
        }
        if(MapUtils.isNotEmpty(map)){
            ThreadLocalUtil.stObj(map);
        }
        return true;
    }



//    /**
//     * 登录失效返回
//     *
//     * @param response
//     * @throws Exception
//     */
//    private void loginVaild(HttpServletResponse response) throws Exception {
//        Result result = new Result();
//        result.error401("请重新登录");
//        response.setContentType("application/json");
//        PrintWriter out = response.getWriter();
//        out.print(JSON.toJSONString(result));
//        out.flush();
//    }
    @Override
    public void afterCompletion(HttpServletRequest request, HttpServletResponse response, Object handler, @Nullable Exception ex) throws Exception {
        ThreadLocalUtil.clear();
    }
}
